/*
 * $Id: gnet_stats.h 8035 2005-04-24 18:51:00Z cbiere $
 *
 * Copyright (c) 2004, Raphael Manfredi
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

#ifndef _if_ui_gtk_gnet_stats_h_
#define _if_ui_gtk_gnet_stats_h_

typedef enum gnet_stats_source {
	GNET_STATS_FULL = 0,
	GNET_STATS_TCP_ONLY = 1,
	GNET_STATS_UDP_ONLY = 2
} gnet_stats_source_t;

#endif /* _if_ui_gtk_gnet_stats_h_ */

/* vi: set ts=4 sw=4 cindent: */
